import { Component, ChangeDetectionStrategy, NgZone, Input, ViewChild, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/helpers/log-message.helper.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const normalizeLogMessage = (/**
 * @param {?} msg
 * @return {?}
 */
(msg) => (Object.assign({}, msg, { type: (msg.type ? msg.type : 'LOG'), timestamp: (msg.timestamp ? msg.timestamp : new Date().toLocaleString()) })));

/**
 * @fileoverview added by tsickle
 * Generated from: lib/log-monitor.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LogMonitorComponent {
    /**
     * @param {?} zone
     */
    constructor(zone) {
        this.zone = zone;
        this.history = [];
        this.theme = 'dark';
        this.icons = true;
        this.customClass = 'log-container';
        this.animated = true;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes['history']) {
            this.history = changes['history'].currentValue.map(normalizeLogMessage);
        }
        if (changes['logStream'] && changes['logStream'].currentValue) {
            this.zone.run((/**
             * @return {?}
             */
            () => {
                /** @type {?} */
                const normalizedMsg = normalizeLogMessage(changes['logStream'].currentValue);
                this.history.push(normalizedMsg);
                setTimeout((/**
                 * @return {?}
                 */
                () => this.scrollToBottom()));
            }));
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this.scrollToBottom();
    }
    /**
     * @private
     * @return {?}
     */
    scrollToBottom() {
        this.container.nativeElement.scrollTop = this.container.nativeElement.scrollHeight;
    }
}
LogMonitorComponent.decorators = [
    { type: Component, args: [{
                selector: 'log-monitor',
                template: "\n<div *ngIf=\"title\" class=\"title-bar\" [ngClass]=\"theme+'-theme'\">&#9002; {{title}}</div>\n<div\n  #container\n  class=\"container\"\n  [ngClass]=\"theme+'-theme'\"\n>\n  <span\n    class=\"msg-item {{'msg-'+(log.type.toLowerCase())}}\"\n    *ngFor=\"let log of history\"\n    [ngClass]=\"{'animated': animated}\"\n  >\n    <span *ngIf=\"icons\" [ngSwitch]=\"log.type\">\n      <ng-container *ngSwitchCase=\"'ERR'\">&#10008;</ng-container>\n      <ng-container *ngSwitchCase=\"'SUCCESS'\">&#10004;</ng-container>\n      <ng-container *ngSwitchCase=\"'LOG'\">&#10097;</ng-container>\n      <ng-container *ngSwitchCase=\"'WARN'\">&#8252;</ng-container>\n      <ng-container *ngSwitchCase=\"'INFO'\">&#8505;</ng-container>\n    </span>\n\n    [{{log.timestamp}}]: {{log.message}}\n  </span>\n\n</div>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".container{position:relative;width:100%;height:100%;padding-top:5px;padding-bottom:5px;overflow-y:auto;font-family:\"Lucida Console\",Monaco,monospace,sans-serif}.animated{-webkit-animation:260ms fadein;animation:260ms fadein}@-webkit-keyframes fadein{from{opacity:0;transform:translateY(-10px)}to{opacity:1;transform:translateY(0)}}@keyframes fadein{from{opacity:0;transform:translateY(-10px)}to{opacity:1;transform:translateY(0)}}.title-bar{padding:5px;font-weight:600}.dark-theme.title-bar{border-bottom:1px solid #3c3c3c;background:#1f1f1f}.light-theme.title-bar{border-bottom:1px solid #a8acad;background:#dbdfe0}.msg-item{display:block;margin-left:6px;font-size:.85em}.msg-list{margin:0;height:100%}.light-theme{color:#212121;background:#ecf0f1}.light-theme .msg-info{color:#2980b9}.light-theme .msg-err{color:#c0392b}.light-theme .msg-success{color:#27ae60}.light-theme .msg-warn{color:#f39c12}.dark-theme{color:#ecf0f1;background:#212121}.dark-theme .msg-info{color:#3498db}.dark-theme .msg-err{color:#e74c3c}.dark-theme .msg-success{color:#2ecc71}.dark-theme .msg-warn{color:#f1c40f}"]
            }] }
];
/** @nocollapse */
LogMonitorComponent.ctorParameters = () => [
    { type: NgZone }
];
LogMonitorComponent.propDecorators = {
    title: [{ type: Input }],
    logStream: [{ type: Input }],
    history: [{ type: Input }],
    theme: [{ type: Input }],
    icons: [{ type: Input }],
    customClass: [{ type: Input }],
    animated: [{ type: Input }],
    container: [{ type: ViewChild, args: ['container', { static: false },] }]
};
if (false) {
    /** @type {?} */
    LogMonitorComponent.prototype.title;
    /** @type {?} */
    LogMonitorComponent.prototype.logStream;
    /** @type {?} */
    LogMonitorComponent.prototype.history;
    /** @type {?} */
    LogMonitorComponent.prototype.theme;
    /** @type {?} */
    LogMonitorComponent.prototype.icons;
    /** @type {?} */
    LogMonitorComponent.prototype.customClass;
    /** @type {?} */
    LogMonitorComponent.prototype.animated;
    /** @type {?} */
    LogMonitorComponent.prototype.container;
    /**
     * @type {?}
     * @private
     */
    LogMonitorComponent.prototype.zone;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/log-monitor.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class LogMonitorModule {
}
LogMonitorModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [LogMonitorComponent],
                exports: [LogMonitorComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/models/log-message.model.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function LogMessage() { }
if (false) {
    /** @type {?|undefined} */
    LogMessage.prototype.type;
    /** @type {?|undefined} */
    LogMessage.prototype.timestamp;
    /** @type {?} */
    LogMessage.prototype.message;
}

/**
 * @fileoverview added by tsickle
 * Generated from: index.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-log-monitor.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { LogMonitorComponent, LogMonitorModule };
//# sourceMappingURL=ngx-log-monitor.js.map
